@@ -4,8 +4,10 @@
 import os
 import shutil
 from pathlib import Path
+from io import BytesIO
 from typing import Callable, List, Union
 from PIL import Image
+import PIL
 import cv2
 import matplotlib.pyplot as plt
 import numpy as np
@@ -16,10 +18,33 @@ from torchvision import transforms
 
 from navalmartin_mir_vision_utils.exceptions import InvalidPILImageMode
 from navalmartin_mir_vision_utils.image_enums import (ImageFileEnumType, ImageLoadersEnumType,
-                                                      IMAGE_LOADERS, IMAGE_STR_TYPES, VALID_PIL_MODES_STR)
+                                                      IMAGE_LOADERS_TYPES_STR, IMAGE_STR_TYPES, VALID_PIL_MODES_STR)
 from navalmartin_mir_vision_utils.io.file_utils import ERROR
 
 
+def is_valid_pil_image_from_bytes_string(image_byte_string: str) -> Image:
+    """Check if the provided bytes correspond to a valid
+    PIL.Image. If IOError or  SyntaxError is raised it returns None
+
+    Parameters
+    ----------
+    image_byte_string: The string bytes that correspond to an image
+
+    Returns
+    -------
+
+    An instance of a PIL.Image if the image is valid or None
+    """
+    try:
+        image = Image.open(BytesIO(image_byte_string))
+        image.verify()
+        return image
+    except (IOError, SyntaxError) as e:
+        print(f"{ERROR} the image_byte_string is corrupted")
+        print(f"Exception message {str(e)}")
+        return None
+
+
 def is_valid_pil_image_file(image: Path) -> Image:
     """Check if the given image is a valid Pillow image
 
@@ -29,7 +54,7 @@ def is_valid_pil_image_file(image: Path) -> Image:
 
     Returns
     -------
-    an instance of a PIL.Image if the image is valid or None
+    An instance of a PIL.Image if the image is valid or None
     """
 
     try:
@@ -208,8 +233,8 @@ def load_images_from_paths(imgs: List[Path], transformer: Callable,
     if len(imgs) == 0:
         raise ValueError("Empty images paths")
 
-    if loader not in IMAGE_LOADERS:
-        raise ValueError(f"Invalid loader. Loader={loader} not in {IMAGE_LOADERS}")
+    if loader not in IMAGE_LOADERS_TYPES_STR:
+        raise ValueError(f"Invalid loader. Loader={loader} not in {IMAGE_LOADERS_TYPES_STR}")
 
     imgs_data = []
     for img in imgs:
@@ -302,8 +327,8 @@ def load_img(path: Path, transformer: Callable = None,
     transform
     """
 
-    if loader.name.upper() not in IMAGE_LOADERS:
-        raise ValueError(f"Invalid image loader={loader.name.upper()} not in {IMAGE_LOADERS}")
+    if loader.name.upper() not in IMAGE_LOADERS_TYPES_STR:
+        raise ValueError(f"Invalid image loader={loader.name.upper()} not in {IMAGE_LOADERS_TYPES_STR}")
 
     if loader == ImageLoadersEnumType.PIL:
         return load_image_as_pillow(path=path, transformer=transformer)
@@ -411,12 +436,13 @@ def save_img(image: Image, filename: Path, img_format: str = None) -> None:
         image.save(filename, format=img_format)
 
 
-def show_img(img) -> None:
+def show_pil_image(image: Image) -> None:
     """Show the image depending on the
     type
 
     Parameters
     ----------
+    image
     img: The image to show
 
     Returns
@@ -424,8 +450,7 @@ def show_img(img) -> None:
 
     """
 
-    # if isinstance(img, PIL.Image):
-    img.show()
+    image.show()
 
 
 def save_img_from_str(img_str: str, encoding: str,
